@@ -2,7 +2,7 @@
 Date         : 2022-10-25 17:21:52
 Author       : BDFD,bdfd2005@gmail.com
 Github       : https://github.com/bdfd
-LastEditTime : 2022-10-26 11:51:51
+LastEditTime : 2022-10-26 12:12:25
 LastEditors  : BDFD
 Description  : 
 FilePath     : \execdata\model_evaluate.py
@@ -30,6 +30,8 @@ def model_evaluate(X_train, X_test, y_train, y_test):
         # "XGBoost" : XGBClassifier()
     }
 
+    models = ['LogisticRegression', 'KNeighbors', 'SVC', 'DecisionTree', 'RandomForest']
+
     for key, classifier in classifiers.items():
         classifier.fit(X_train, y_train)
         train_score = classifier.score(X_train, y_train)
@@ -37,7 +39,8 @@ def model_evaluate(X_train, X_test, y_train, y_test):
         test_score = classifier.score(X_test, y_test)
         test_scores.append(test_score)
 
-    print(train_scores)
-    print(test_scores)
+    print(f'model list is {models}')
+    for n in range(5):
+        print(f'for model {models[n]} with the train_score:{train_scores[n]} and test_score:{test_scores[n]} ')
     
-    return train_score, test_score
\ No newline at end of file
+    return train_score, test_score, models
\ No newline at end of file
