@@ -2,7 +2,7 @@
 Date         : 2022-10-25 17:21:52
 Author       : BDFD,bdfd2005@gmail.com
 Github       : https://github.com/bdfd
-LastEditTime : 2022-10-25 17:27:30
+LastEditTime : 2022-10-26 11:50:41
 LastEditors  : BDFD
 Description  : 
 FilePath     : \execdata\preprocess.py
@@ -10,11 +10,19 @@ Copyright (c) 2022 by BDFD, All Rights Reserved.
 '''
 
 
-from numpy import numpy as np
+import numpy as np
 from sklearn.preprocessing import LabelEncoder
+from sklearn.model_selection import train_test_split
 
 def encode(df):
     lable = LabelEncoder()
     for column in df:
         if df[column].dtypes == 'object':
-            df[column] = lable.fit_transform(df[column])
\ No newline at end of file
+            df[column] = lable.fit_transform(df[column])
+    return df
+
+def split(df):
+    X = df.iloc[:,1:-1]
+    y = df.iloc[:,-1]
+    X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.2, random_state=66)
+    return X_train, X_test, y_train, y_test
\ No newline at end of file
